@@ -30,8 +30,7 @@ parser.add_argument(
 parser.add_argument(
     "-e", "--rm_already_exist", help="remove words system dict already exist"
 )
-parser.add_argument("-r", "--sudachi_setting",
-                    help="the setting file in JSON format")
+parser.add_argument("-r", "--sudachi_setting", help="the setting file in JSON format")
 parser.add_argument("-s", "--sudachi_dict_type", help="sudachidict type")
 parser.add_argument(
     "--ignore",
